@@ -1,18 +1,13 @@
 /*
  * This file is part of GPaste.
  *
- * Copyright (c) 2010-2017, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
+ * Copyright (c) 2010-2019, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
  */
-/* -*- mode: js2; js2-basic-offset: 4; indent-tabs-mode: nil -*- */
 
-const Lang = imports.lang;
+const { GLib, GPaste, St } = imports.gi;
 
-const St = imports.gi.St;
-
-var GPasteEmptyHistoryItem = new Lang.Class({
-    Name: 'GPasteEmptyHistoryItem',
-
-    _init: function(client) {
+class GPasteEmptyHistoryItem {
+    constructor(client, settings, menu) {
         this.actor = new St.Button({
             reactive: true,
             can_focus: true,
@@ -23,11 +18,12 @@ var GPasteEmptyHistoryItem = new Lang.Class({
         this.actor.child = new St.Icon({ icon_name: 'edit-clear-all-symbolic' });
 
         this.actor.connect('clicked', function() {
+            menu.itemActivated();
             client.get_history_name((client, result) => {
                 const name = client.get_history_name_finish(result);
 
-                client.empty_history(name, null);
+                GPaste.util_empty_with_confirmation (client, settings, name);
             });
         });
     }
-});
+};
